translate.misc.diff_match_patch

Package translate :: Package misc :: Module diff_match_patch |
[hide private]
[frames] | no frames]

# Module diff_match_patch

source code

    Diff Match and Patch

    Copyright 2006 Google Inc.
    http://code.google.com/p/google-diff-match-patch/

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

      http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

Author: fraser@google.com (Neil Fraser)

Classes | [hide private]
| diff_match_patch Class containing the diff, match and patch methods.
| patch_obj Class representing one patch operation.

Variables | [hide private]
| __package__ = ``'``translate.misc``'``

Imports: time, re